@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: wai-extra
 version: 3.0.15
-id: wai-extra-3.0.15-954ac840c460f6e3c2fb191ca01c5fce
-key: waiex_5XqEGpiYHwy9vrHr9YSBBx
+id: wai-extra-3.0.15-2f88b45989ced36024c3ff3943866d23
+key: waiex_2AYrLQnSPnOFvG1Pof9QqB
 license: MIT
 maintainer: michael@snoyman.com
 stability: Stable
@@ -96,7 +96,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-extra-3.0.15
 library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-extra-3.0.15
 data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-extra-3.0.15
-hs-libraries: HSwai-extra-3.0.15-5XqEGpiYHwy9vrHr9YSBBx
+hs-libraries: HSwai-extra-3.0.15-2AYrLQnSPnOFvG1Pof9QqB
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
@@ -126,8 +126,8 @@ depends:
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
     vault-0.3.0.6-2c2444df5306907b16aaa509d25c29c9
     void-0.7.1-5298c6b3a32576797627b9b87532f9cb
-    wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
-    wai-logger-2.2.4.1-9478a6051df96b8d5b3214f7fcca2185
+    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
+    wai-logger-2.2.4.1-fb66803d5627851b4e6cf4f9505489de
     word8-0.1.2-9a296ac80618be494d93f29b398e749d
     zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
 haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
